%%
%% This is file `sjtu-thesis-zh.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% sjtutex.dtx  (with options: `thesis-i18n,zh')
%% 
%%     Copyright (C) SJTUG
%%       2018--2025 Weijian Wu   <alexarawu@outlook.com>
%%       2022--2025 Zilong Li    <logcreative@outlook.com>
%%       2024--2025 Boshi Yuan   <nemoyuan2008@outlook.com>
%% 
%%     This work may be distributed and/or modified under the
%%     conditions of the LaTeX Project Public License, either
%%     version 1.3c of this license or (at your option) any later
%%     version. The latest version of this license is in:
%% 
%%       http://www.latex-project.org/lppl.txt
%% 
%%     and version 1.3 or later is part of all distributions of
%%     LaTeX version 2005/12/01 or later.
%% 
\GetIdInfo$Id: sjtutex.dtx d611a82 2025-02-12 23:33:21 +0800 Alexara Wu <alexarawu@outlook.com> $
  {Chinese config for thesis (SJTUTeX)}
\ProvidesExplFile{sjtu-thesis-zh.def}
  {\ExplFileDate}{2.2}{\ExplFileDescription}
\__sjtu_symbol_const:nn { white_square } { "25A1 }
\__sjtu_name_const_from_clist:nnnn { zh }
  { degree_level } { \g__sjtu_thesis_type_int }
  { 学士, 硕士, 博士 }
\clist_map_inline:nn
  {
    { univ             } { 上海交通大学           } ,
    { address          } { 中国・上海             } ,
    { thesis           } { 学位论文               } ,
    { title_page       } { 题名页                 } ,
    { declaration      } { 原创性声明及使用授权书 } ,
    { orig_decl        } { 原创性声明             } ,
    { auth_decl        } { 使用授权书             } ,
    { decl_author      } { 学位论文作者           } ,
    { decl_supervisor  } { 指导教师               } ,
    { abstract         } { 摘 \protect \quad 要   }
  }
  { \__sjtu_name_const:nnn { zh } #1 }
\clist_map_inline:nn
  {
    { author           } { 姓名              } ,
    { id               } { 学号              } ,
    { supervisor       } { 导师              } ,
    { assoc_supervisor } { 副导师            } ,
    { co_supervisor    } { 联合导师          } ,
    { department       } { 院系              } ,
    { major            } { 学科 \, / \, 专业 } ,
    { degree           } { 申请学位          }
  }
  { \__sjtu_name_set:nnn { zh } #1 }
\keys_define:nn { sjtu / info / zh }
  {
    subject          .initial:e =
      {
        \exp_not:V \c__sjtu_name_univ_zh_tl
        \exp_not:V \c__sjtu_name_degree_level_zh_tl
        \exp_not:V \c__sjtu_name_thesis_zh_tl
      }
  }
\DeclareInstanceCopy { sjtu / page }
  { title / zh } { title a }
\endinput
%%
%% End of file `sjtu-thesis-zh.def'.
