%%
%% This is file `sjtu-math-font-cambria.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% sjtutex.dtx  (with options: `font,math,otf,cambria')
%% 
%%     Copyright (C) SJTUG
%%       2018--2025 Weijian Wu   <alexarawu@outlook.com>
%%       2022--2025 Zilong Li    <logcreative@outlook.com>
%%       2024--2025 Boshi Yuan   <nemoyuan2008@outlook.com>
%% 
%%     This work may be distributed and/or modified under the
%%     conditions of the LaTeX Project Public License, either
%%     version 1.3c of this license or (at your option) any later
%%     version. The latest version of this license is in:
%% 
%%       http://www.latex-project.org/lppl.txt
%% 
%%     and version 1.3 or later is part of all distributions of
%%     LaTeX version 2005/12/01 or later.
%% 
\GetIdInfo$Id: sjtutex.dtx d611a82 2025-02-12 23:33:21 +0800 Alexara Wu <alexarawu@outlook.com> $
  {Cambria math fonts definition (SJTUTeX)}
\ProvidesExplFile{sjtu-math-font-cambria.def}
  {\ExplFileDate}{2.2}{\ExplFileDescription}
\__sjtu_if_engine_opentype:TF
  {
    \RequirePackage { unicode-math }
    \setmathfont { Cambria~Math }
    \setmathrm { Cambria }
    \setmathsf { Calibri }
    \setmathtt { Consolas } [ Scale = 0.95 ]
  }
  { \__sjtu_fontset_error:nn { math } { cambria } }
\endinput
%%
%% End of file `sjtu-math-font-cambria.def'.
