%%
%% This is file `sjtu-text-font-times.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% sjtutex.dtx  (with options: `font,text,type1,times')
%% 
%%     Copyright (C) SJTUG
%%       2018--2025 Weijian Wu   <alexarawu@outlook.com>
%%       2022--2025 Zilong Li    <logcreative@outlook.com>
%%       2024--2025 Boshi Yuan   <nemoyuan2008@outlook.com>
%% 
%%     This work may be distributed and/or modified under the
%%     conditions of the LaTeX Project Public License, either
%%     version 1.3c of this license or (at your option) any later
%%     version. The latest version of this license is in:
%% 
%%       http://www.latex-project.org/lppl.txt
%% 
%%     and version 1.3 or later is part of all distributions of
%%     LaTeX version 2005/12/01 or later.
%% 
\GetIdInfo$Id: sjtutex.dtx d611a82 2025-02-12 23:33:21 +0800 Alexara Wu <alexarawu@outlook.com> $
  {Times text fonts definition (SJTUTeX)}
\ProvidesExplFile{sjtu-text-font-times.def}
  {\ExplFileDate}{2.2}{\ExplFileDescription}
\__sjtu_if_engine_opentype:TF
  {
    \setmainfont { Times~New~Roman } [ Ligatures = Rare ]
    \setsansfont { Arial } [ Scale = 0.94 ]
    \setmonofont { Courier~New }
  }
  {
    \tl_set:Nn \encodingdefault { T1 }
    \tl_set:Nn \rmdefault { ptm }
    \tl_set:Nn \Hv@scale { 0.94 }
    \tl_set:Nn \sfdefault { phv }
    \tl_set:Nn \ttdefault { pcr }
  }
\endinput
%%
%% End of file `sjtu-text-font-times.def'.
