%%
%% This is file `sjtu-lang-de.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% sjtutex.dtx  (with options: `lang,de')
%% 
%%     Copyright (C) SJTUG
%%       2018--2025 Weijian Wu   <alexarawu@outlook.com>
%%       2022--2025 Zilong Li    <logcreative@outlook.com>
%%       2024--2025 Boshi Yuan   <nemoyuan2008@outlook.com>
%% 
%%     This work may be distributed and/or modified under the
%%     conditions of the LaTeX Project Public License, either
%%     version 1.3c of this license or (at your option) any later
%%     version. The latest version of this license is in:
%% 
%%       http://www.latex-project.org/lppl.txt
%% 
%%     and version 1.3 or later is part of all distributions of
%%     LaTeX version 2005/12/01 or later.
%% 
\GetIdInfo$Id: sjtutex.dtx d611a82 2025-02-12 23:33:21 +0800 Alexara Wu <alexarawu@outlook.com> $
  {German specific definition (SJTUTeX)}
\ProvidesExplFile{sjtu-lang-de.def}
  {\ExplFileDate}{2.2}{\ExplFileDescription}
\keys_define:nn { sjtu / private }
  {
    lang / de .code:n =
      {
        \tl_set_eq:NN \l__sjtu_lang_tl \l_keys_value_tl
        \tl_set:Nn \languagename { ngerman }
        \normalfont
        \ctex_set:n { autoindent = 1.5 em }
      } ,
    de .meta:n = { lang = de } ,
    de .groups:n = { lang }
  }
\cs_set_eq:NN \__sjtu_title_case_aux_de:n \MakeUppercase
\clist_map_inline:nn
  {
    { keywords } { Schlüsselwörter } ,
    { info_sep } { \hbox { :~ }    } ,
    { item_sep } { ,~              }
  }
  { \__sjtu_name_const:nnn { de } #1 }
\clist_const:Nn \c__sjtu_name_month_de_clist
  {
    Januar, Februar, März, April, Mai, Juni,
    Juli, August, September, Oktober, November, Dezember
  }
\cs_new:Npn \__sjtu_date_aux_de:nnn #1#2#3
  {
    \clist_item:Nn \c__sjtu_name_month_de_clist {#2} ~
    {#3} ,~ \int_to_arabic:n {#1}
  }
\cs_new:Npn \__sjtu_date_aux_de:w #1-#2-#3 \q_stop
  { \__sjtu_date_aux_de:nnn {#1} {#2} {#3} }
\cs_new:Npn \__sjtu_date_aux_short_de:nn #1#2
  {
    \clist_item:Nn \c__sjtu_name_month_de_clist {#2} ,~
    \int_to_arabic:n {#1}
  }
\cs_new:Npn \__sjtu_date_aux_short_de:w #1-#2 \q_stop
  { \__sjtu_date_aux_short_de:nn {#1} {#2} }
\endinput
%%
%% End of file `sjtu-lang-de.def'.
