%%
%% This is file `sjtu-thesis-de.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% sjtutex.dtx  (with options: `thesis-i18n,de')
%% 
%%     Copyright (C) SJTUG
%%       2018--2025 Weijian Wu   <alexarawu@outlook.com>
%%       2022--2025 Zilong Li    <logcreative@outlook.com>
%%       2024--2025 Boshi Yuan   <nemoyuan2008@outlook.com>
%% 
%%     This work may be distributed and/or modified under the
%%     conditions of the LaTeX Project Public License, either
%%     version 1.3c of this license or (at your option) any later
%%     version. The latest version of this license is in:
%% 
%%       http://www.latex-project.org/lppl.txt
%% 
%%     and version 1.3 or later is part of all distributions of
%%     LaTeX version 2005/12/01 or later.
%% 
\GetIdInfo$Id: sjtutex.dtx d611a82 2025-02-12 23:33:21 +0800 Alexara Wu <alexarawu@outlook.com> $
  {German config for thesis (SJTUTeX)}
\ProvidesExplFile{sjtu-thesis-de.def}
  {\ExplFileDate}{2.2}{\ExplFileDescription}
\__sjtu_name_const_from_clist:nnnn { de }
  { degree_level } { \g__sjtu_thesis_type_int }
  { Bachelor, Master, Doktor }
\clist_map_inline:nn
  {
    { univ             } { Shanghai~ Jiao~ Tong~ Universität } ,
    { address          } { Shanghai,~ VR~ China              } ,
    { title_page       } { Titelblatt                        } ,
    { declaration      } { Eidesstattliche~ Erklärung        } ,
    { abstract         } { Abstrakt                          }
  }
  { \__sjtu_name_const:nnn { de } #1 }
\clist_map_inline:nn
  {
    { author           } { Autor/in         } ,
    { supervisor       } { Betreuer/in      } ,
    { assoc_supervisor } { Zweitbetreuer/in } ,
    { co_supervisor    } { Co-Betreuer/in   }
  }
  { \__sjtu_name_set:nnn { de } #1 }
\keys_define:nn { sjtu / info / de }
  {
    subject          .initial:e =
      {
        Eine~ Dissertation~ Eingereicht~ an \exp_not:N \\
        der~ { \exp_not:V \c__sjtu_name_univ_de_tl }~ für~
        { \exp_not:V \c__sjtu_name_degree_level_de_tl } titel
      }
  }
\DeclareInstanceCopy { sjtu / page }
  { title / de } { title b }
\endinput
%%
%% End of file `sjtu-thesis-de.def'.
