%%
%% This is file `sjtu-math-font-newtx.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% sjtutex.dtx  (with options: `font,math,type1,newtx')
%% 
%%     Copyright (C) SJTUG
%%       2018--2025 Weijian Wu   <alexarawu@outlook.com>
%%       2022--2025 Zilong Li    <logcreative@outlook.com>
%%       2024--2025 Boshi Yuan   <nemoyuan2008@outlook.com>
%% 
%%     This work may be distributed and/or modified under the
%%     conditions of the LaTeX Project Public License, either
%%     version 1.3c of this license or (at your option) any later
%%     version. The latest version of this license is in:
%% 
%%       http://www.latex-project.org/lppl.txt
%% 
%%     and version 1.3 or later is part of all distributions of
%%     LaTeX version 2005/12/01 or later.
%% 
\GetIdInfo$Id: sjtutex.dtx d611a82 2025-02-12 23:33:21 +0800 Alexara Wu <alexarawu@outlook.com> $
  {New TX math fonts definition (SJTUTeX)}
\ProvidesExplFile{sjtu-math-font-newtx.def}
  {\ExplFileDate}{2.2}{\ExplFileDescription}
\tl_set_eq:NN \l__sjtu_save_encodingdefault_tl \encodingdefault
\tl_set_eq:NN \l__sjtu_save_rmdefault_tl \rmdefault
\tl_set_eq:NN \l__sjtu_save_sfdefault_tl \sfdefault
\tl_set_eq:NN \l__sjtu_save_ttdefault_tl \ttdefault
\tl_set:Nn \encodingdefault { OT1 }
\tl_set:Nn \rmdefault { ntxtlf }
\tl_set:Nn \qhv@scale { 0.94 }
\tl_set:Nn \sfdefault { qhv }
\tl_set:Nn \ttdefault { qcr }
\RequirePackage { newtxmath }
\tl_set_eq:NN \encodingdefault \l__sjtu_save_encodingdefault_tl
\tl_set_eq:NN \rmdefault \l__sjtu_save_rmdefault_tl
\tl_set_eq:NN \sfdefault \l__sjtu_save_sfdefault_tl
\tl_set_eq:NN \ttdefault \l__sjtu_save_ttdefault_tl
\__sjtu_set_unimath_symbol:
\endinput
%%
%% End of file `sjtu-math-font-newtx.def'.
