%%
%% This is file `sjtu-cjk-font-founder.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% sjtutex.dtx  (with options: `font,cjk,founder')
%% 
%%     Copyright (C) SJTUG
%%       2018--2025 Weijian Wu   <alexarawu@outlook.com>
%%       2022--2025 Zilong Li    <logcreative@outlook.com>
%%       2024--2025 Boshi Yuan   <nemoyuan2008@outlook.com>
%% 
%%     This work may be distributed and/or modified under the
%%     conditions of the LaTeX Project Public License, either
%%     version 1.3c of this license or (at your option) any later
%%     version. The latest version of this license is in:
%% 
%%       http://www.latex-project.org/lppl.txt
%% 
%%     and version 1.3 or later is part of all distributions of
%%     LaTeX version 2005/12/01 or later.
%% 
\GetIdInfo$Id: sjtutex.dtx d611a82 2025-02-12 23:33:21 +0800 Alexara Wu <alexarawu@outlook.com> $
  {Founder CJK fonts definition (SJTUTeX)}
\ProvidesExplFile{sjtu-cjk-font-founder.def}
  {\ExplFileDate}{2.2}{\ExplFileDescription}
\__sjtu_if_engine_opentype:TF
  {
    \__sjtu_if_main_lang_ja:TF
      {
        \setCJKmainfont { ipam.ttf } [ AutoFakeBold = 3 ]
        \setCJKsansfont { ipag.ttf } [ AutoFakeBold = 3 ]
        \setCJKmonofont { ipag.ttf }
        \setCJKfamilyfont { jamin  } { ipam.ttf } [ AutoFakeBold = 3 ]
        \setCJKfamilyfont { jagoth } { ipag.ttf } [ AutoFakeBold = 3 ]
        \NewDocumentCommand \mincho   { } { \CJKfamily { jamin   } }
        \NewDocumentCommand \gothic   { } { \CJKfamily { jagoth  } }
      }
      {
        \setCJKmainfont { FZShuSong-Z01  }
          [ AutoFakeBold = 3 , ItalicFont = FZKai-Z03 ]
        \setCJKsansfont { FZHei-B01      } [ AutoFakeBold = 3 ]
        \setCJKmonofont { FZFangSong-Z02 }
      }
    \setCJKfamilyfont { zhsong } { FZShuSong-Z01  }
      [ AutoFakeBold = 3 , ItalicFont = FZKai-Z03 ]
    \setCJKfamilyfont { zhhei  } { FZHei-B01      } [ AutoFakeBold = 3 ]
    \setCJKfamilyfont { zhkai  } { FZKai-Z03      }
    \setCJKfamilyfont { zhfs   } { FZFangSong-Z02 }
    \NewDocumentCommand \songti   { } { \CJKfamily { zhsong  } }
    \NewDocumentCommand \heiti    { } { \CJKfamily { zhhei   } }
    \NewDocumentCommand \fangsong { } { \CJKfamily { zhfs    } }
    \NewDocumentCommand \kaishu   { } { \CJKfamily { zhkai   } }
  }
  {
    \__sjtu_if_main_lang_ja:TF
      { \__sjtu_fontset_error:nn { cjk } { founder } }
      { \ctex_file_input:n { ctex-fontset-founder.def } }
  }
\endinput
%%
%% End of file `sjtu-cjk-font-founder.def'.
